mailr3829 - /1.3/generic_fns/sequence.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 22, 2007 - 18:01:
Author: bugman
Date: Thu Nov 22 18:01:07 2007
New Revision: 3829

URL: http://svn.gna.org/viewcvs/relax?rev=3829&view=rev
Log:
Updated the docstring of generic_fns.sequence.read().  This is now in the 
epydoc format.


Modified:
    1.3/generic_fns/sequence.py

Modified: 1.3/generic_fns/sequence.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/sequence.py?rev=3829&r1=3828&r2=3829&view=diff
==============================================================================
--- 1.3/generic_fns/sequence.py (original)
+++ 1.3/generic_fns/sequence.py Thu Nov 22 18:01:07 2007
@@ -28,7 +28,26 @@
 
 
 def read(file=None, dir=None, mol_name_col=None, res_num_col=0, 
res_name_col=1, spin_num_col=None, spin_name_col=None, sep=None):
-    """Function for reading sequence data."""
+    """Function for reading molecule, residue, and/or spin sequence data.
+
+    @param file:            The name of the file to open.
+    @type file:             str
+    @param dir:             The directory containing the file (defaults to 
the current directory if
+                            None).
+    @type dir:              str or None
+    @param mol_name_col:    The column containing the molecule name 
information.
+    @type mol_name_col:     int or None
+    @param res_name_col:    The column containing the residue name 
information.
+    @type res_name_col:     int or None
+    @param res_num_col:     The column containing the residue number 
information.
+    @type res_num_col:      int or None
+    @param spin_name_col:   The column containing the spin name information.
+    @type spin_name_col:    int or None
+    @param spin_num_col:    The column containing the spin number 
information.
+    @type spin_num_col:     int or None
+    @param sep:             The column seperator which, if None, defaults to 
whitespace.
+    @type sep:              str or None
+    """
 
     # Test if sequence data already exists.
     if sequence_exists():




Related Messages


Powered by MHonArc, Updated Thu Nov 22 18:20:14 2007